Key Terms
=========

==================================== =====================
amortized analysis                   map
deterministic finite automaton (DFA) octree
DFA graph                            pixel
dictionary                           public key encryption
dithering                            quantization
DNA string                           RSA algorithm
KMP graph                            skip list
Knuth-Morris-Pratt (KMP)             substring
level                                tower
==================================== =====================

